@@ -23,14 +23,14 @@ def get_paths():
     root_02450private = root_02450private.replace("\\", "/")
 
     if not os.path.isdir(root_02450private):
-        root_02450private = root_02450public+'/pythontools/imlbox'
-        warn('pythontools/imlbox/core/info_paths.py: 02450private repo not found')
+        root_02450private = f'{root_02450public}/{num}private'
+        warn('Private repository not found at the expected location.')
         warn('Using mock info from resources folder at:')
         warn(root_02450private)
         # Tue: always overwrite semester path.
-        semester_path = root_02450private +"/resources/mock_semesters/" + semester_id()
-    else:
-        semester_path = root_02450private + "/semesters/" + semester_id()
+        # semester_path = root_02450private +"/resources/mock_semesters/" + semester_id()
+    # else:
+    semester_path = root_02450private + "/semesters/" + semester_id()
 
     if not os.path.isdir(semester_path):
         os.makedirs(semester_path)
